@@ -1,4 +1,5 @@
 import numpy as np
+import pandas as pd
 from scipy import stats
 from sklearn.metrics import mean_squared_error
 
@@ -11,7 +12,7 @@ def get_metrics(df, truth = 'truth', pred = 'pred', return_dict = False):
     mbe = np.mean(df.dropna()[pred] - df.dropna()[truth])
     mae = (df.dropna()[pred] - df.dropna()[truth]).abs().mean()
     if return_dict:
-        return {
+        return pd.DataFrame.from_dict([{
             'R2': r2, 
             'Slope': slope, 
             'RMSE': rmse, 
@@ -20,7 +21,7 @@ def get_metrics(df, truth = 'truth', pred = 'pred', return_dict = False):
             'Intercept': intercept, 
             'p-value': p_value, 
             'std_err': std_err
-        }
+        }])
     else:
         return r2, slope, rmse, mbe, mae, intercept, p_value, std_err
 
@@ -108,19 +109,22 @@ def train_ml(
 
 def test_ml(X_test, y_test, regr):
     res = y_test.copy() # y_test is 2D pandas dataframe.
-    res.columns = ['true']
+    res.columns = ['truth']
     res['pred'] = regr.predict(X_test)
     return res
 
 # ===============================================================================================================================
 # Deep learning neural networks
 
-from tensorflow import keras
-from tensorflow.keras import layers
-from tensorflow.keras import models
-# from keras.layers import Dropout
-from keras.callbacks import EarlyStopping
-from scitbx.stutils import *
+try:
+    from tensorflow import keras
+    from tensorflow.keras import layers
+    from tensorflow.keras import models
+    # from keras.layers import Dropout
+    from keras.callbacks import EarlyStopping
+    from scitbx.stutils import *
+except Exception as e:
+    print(e)
 
 def train_lstm(X_train, y_train, nfeature, ntime, verbose = 2, epochs = 200, batch_size = 64):
     # create and fit the LSTM network
